#!/bin/sh
#copyright	"%c%"
#ident	"@(#)opensrc:src/samba/samba.sh /main/uw714mp/16"

#
# This directory contains:
#
# dist/			Source files from samba-${VER} distribution.
# patches/*		Patches to be applied.
# samba.sh		Build script (this file).
# SCO			subdirectory containing:
# 	samba.init		/etc/init.d script.
# 	samba.pam		/etc/pam.d/samba file.
# 	samba.inetd.sed		Sed script to modify /etc/inet/inetd.conf file.
# 	samba.services.sed	Sed script to modify /etc/inet/services file. 
#	.directory		Docview glue.
# 	DOS_samba*		""
#

set -x

VER=3.0.24
if [ -f "${ROOT}/${MACH}/usr/lib/cups/bin/cups-config" ]
then
	CUPS_CONFIG=${ROOT}/${MACH}/usr/lib/cups/bin/cups-config
else
	CUPS_CONFIG=/usr/lib/cups/bin/cups-config
fi
KRB5CONFIG=${TOOLS}/usr/lib/heimdal/bin/krb5-config
LDAP_LIBS=-lldap
RANLIB=true
export VER CUPS_CONFIG KRB5CONFIG LDAP_LIBS RANLIB

#
# We need GNU awk and GNU make.
#
AWK=/usr/gnu/bin/gawk; export AWK
if [ ! -f "$AWK" ]
then
	AWK=/usr/add-on/public/bin/gawk; export AWK
fi
[ ! -x $AWK ] && {
	echo "ERROR: $AWK not found" >&2
	exit 1
}

MAKE=/usr/gnu/bin/make; export MAKE
[ ! -x $MAKE ] && {
	echo "ERROR: $MAKE not found" >&2
	exit 1
}

CFLAGS="$CFLAGS -Kthread"
export CFLAGS

set -e

#
# Apply patches.
#
cd dist
for patch in ${VER}-port
do
	[ -f ../patches/${patch}.applied ] || {
		${TOOLS}/usr/gnu/bin/patch -b -p1 -i ../patches/${VER}-port.patch
		/bin/date > ../patches/${patch}.applied
	}
done
cd ..

#
# Copy NSS files.
# Note: Do this before configure so that configure finds nss.h
#
[ -f $TOOLS/usr/include/nss.h ] && {
   diff patches/nss.h $TOOLS/usr/include/nss.h > /dev/null || {
      echo "$TOOLS/usr/include/nss.h exists and is different. Exiting."
      exit 1
   }
}

[ -n "$TOOLS" ] && {
	[ -d ${TOOLS}/usr/include ] || mkdir -p ${TOOLS}/usr/include
}
[ -n "$TOOLS" ] && /bin/cp patches/nss.h $TOOLS/usr/include/
[ -n "$TOOLS" ] && /bin/cp patches/nss_compat.c dist/source/nsswitch/
[ -n "$TOOLS" ] && /bin/cp patches/winbind_nss_uw7.c dist/source/nsswitch/

#
# Compiler can optimize out function calls but smbd/msdfs.c has a bad
# optimize, so turn it off.
#
# TODO
# Try to fix smbd/msdfs.c.
#
samba_cv_optimize_out_funcation_calls=no
export samba_cv_optimize_out_funcation_calls
    
cd dist/source/
    
#
# Configure.
#
# Use --with-libsmbclient otherwise static library does not get installed.
#
# TODO
# 1. We have bigcrypt() in libcrypt but configure does not detect it.
# 2. We have cups, explore enabling it in next release.
#
    
LD_LIBRARY_PATH=${TOOLS}/usr/lib:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

./configure \
	--cache-file=/dev/null \
	--prefix=/usr \
        --with-libdir=/usr/lib/samba \
        --with-configdir=/etc/samba \
        --with-logfilebase=/var/log/samba \
        --with-privatedir=/etc/samba/private \
        --with-lockdir=/var/lib/samba \
        --with-piddir=/var/lib/samba \
        --with-swatdir=/usr/share/samba/swat \
	--enable-cups \
	--enable-iprint \
	--with-mandir=/usr/man \
	--with-libiconv=/usr \
	--with-ldap \
	--with-includedir=${TOOLS}/usr/lib \
	--with-krb5=${TOOLS}/usr/lib/heimdal \
	--with-ads \
	--with-pam \
	--with-pam_smbpass \
	--with-syslog \
	--with-utmp \
	--with-libsmbclient \
	--with-winbind \
	--with-pammodulesdir=/usr/lib/security \
	--with-included-popt

#
# Make and install.
# The default shell is /bin/sh which does not work, so use /bin/ksh.
#
$MAKE SHELL=/bin/ksh DESTDIR=$ROOT/$MACH install

#
# Install NSS pam and winbind files.
#
$INSTALL -d $ROOT/$MACH/usr/lib/nss
$INSTALL nsswitch/winbind.so $ROOT/$MACH/usr/lib/nss/
$INSTALL nsswitch/wins.so $ROOT/$MACH/usr/lib/nss/

cd ..

#
# Install a sample config file.
#
$INSTALL -d $ROOT/$MACH/etc/samba
$INSTALL examples/smb.conf.default $ROOT/$MACH/etc/samba/

#
# Install COPYING file.
#
$INSTALL -d $ROOT/$MACH/usr/share/samba
$INSTALL COPYING $ROOT/$MACH/usr/share/samba/

#
# Install WHATSNEW.txt file. (It is referenced by samba doc).
#
$INSTALL -d $ROOT/$MACH/usr/share/samba/swat/help
$INSTALL WHATSNEW.txt $ROOT/$MACH/usr/share/samba/swat/help/

#
# Install schema file.
#
$INSTALL -d $ROOT/$MACH/etc/openldap/schema
$INSTALL examples/LDAP/samba.schema $ROOT/$MACH/etc/openldap/schema/

cd ..

#
# Install startup script.
#
$INSTALL -d $ROOT/$MACH/etc/init.d
$INSTALL SCO/samba.init $ROOT/$MACH/etc/init.d/samba

#
# Install pam config file.
#
$INSTALL -d $ROOT/$MACH/etc/pam.d
$INSTALL SCO/samba.pam $ROOT/$MACH/etc/pam.d/samba

#
# Install sed scripts.
#
$INSTALL -d $ROOT/$MACH/etc/inet
$INSTALL SCO/samba.inetd.sed $ROOT/$MACH/etc/inet/
$INSTALL SCO/samba.services.sed $ROOT/$MACH/etc/inet/

#
# Install docview glue.
#
DOSgroup=/usr/share/meta/doc/HelpTopics/DOShome/DOSgroup
$INSTALL -d $ROOT/$MACH/${DOSgroup}/DOS_samba

$INSTALL SCO/.directory $ROOT/$MACH/${DOSgroup}/DOS_samba/.directory

$INSTALL SCO/DOS_sambaGUIDE.desktop \
$ROOT/$MACH/${DOSgroup}/DOS_samba/DOS_sambaGUIDE.desktop
$INSTALL SCO/DOS_sambaHOWTO.desktop \
$ROOT/$MACH/${DOSgroup}/DOS_samba/DOS_sambaHOWTO.desktop
$INSTALL SCO/DOS_sambaLIB.desktop \
$ROOT/$MACH/${DOSgroup}/DOS_samba/DOS_sambaLIB.desktop
$INSTALL SCO/DOS_sambaMAN.desktop \
$ROOT/$MACH/${DOSgroup}/DOS_samba/DOS_sambaMAN.desktop
$INSTALL SCO/DOS_sambaUSE.desktop \
$ROOT/$MACH/${DOSgroup}/DOS_samba/DOS_sambaUSE.desktop

#
# Fix location of using_samba directory:
#
mv $ROOT/$MACH/usr/share/samba/swat/using_samba \
   $ROOT/$MACH/usr/share/samba/swat/help/using_samba

#
# Remove nss.h from cross environment so that others do not pick it up.
#
/bin/rm $TOOLS/usr/include/nss.h

exit 0
